<?php  /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Advanced Google Maps API PHP Abstraction implementation
 *
 * PHP 4 and 5
 *
 *
 * @category   Services
 * @package    GMap
 * @author     Steven J Scott <webmaster@sjscott.net>
 * @copyright  2005 SJScott Enterprise
 * @license    GPL
 * @version    $Id: GMap.php,v 1.80 2005/02/16 02:16:00 LIQID Exp $
 * @link       http://www.sjscott.net
 */

require_once('GMap/GMarker.php');
require_once('GMap/GPoint.php');
require_once('GMap/GEvent.php');


class GMap {

	/**
	 * GMap::api_key
	 * @var string :: google maps api key
	 **/
	var $api_key = null;
	
	/**
	 * GMap::gmarkers
	 * @var array :: array of GMap marker objects
	 **/
	var $gmarkers = array();
	
	/**
	 * GMap::events
	 * @var array :: array of GEvent objects
	 **/
	var $events = array();
	
	/**
	 * GMap::gmap_div
	 * @var string the name of the div element holding the map
	 **/
	var $div_id = 'gmap_div';
	
	
	/**
	 * GMap::zoom_level
 	 * @var int Zoom level default is 4
 	 **/
 	var $zoom_level = 6;
 	
 	/**
 	 * GMap::home_point
 	 * @var home_point 
 	 */
 	var $home_point = null;


	/**
	 * constructor
	 *
	 * @param string Google Maps API Key. Not sure if google retain their format for key 
	 * so for not any key is accepted
	 * @param float starting longitude
	 * @param float starting latitude
	 **/
    function GMap($key, $start_lon=null, $start_lat=null) {
	
		$this->api_key = $key;
		
		if ($start_lon && $start_lat ){
			$this->home_point = new GPoint($start_lon,$start_lat);
		}
	
	}
	
	
	/**
	 * GMap::render()
	 * 
	 * displays the single map including the script includes with the key
	 * this is designed so it doesn't have to be called from the onload command.
	 **/
	function render( $gdiv = null, $wth = null, $hth = null ){
		$html = '';
		$gdiv = $gdiv ? $gdiv : $this->div_id;
		
 		// *********************************
 		// generate the main js scripts
		$html .=  '<style type="text/css">  v\:* {   behavior:url(#default#VML);  } #gmap_div	{ height:500px; width:500px; }</style>'."\n"
			. "	<div id=\"$gdiv\" class=\"$gdiv\"></div>\n"		
			. "	<!--//  Google Map API generated by SJS GMap  -->\n"
			. '	<script src="http://maps.google.com/maps?file=api&v=1&key=' . $this->api_key . '" type="text/javascript"></script>' . "\n"
			. "	<script type=\"text/javascript\">\n //<![CDATA[ \n\n"
 	        . "	var map = new GMap(document.getElementById(\"$gdiv\"));\n"
 	        . '	map.centerAndZoom(new GPoint(' . $this->home_point->point_lon . ', ' . $this->home_point->point_lat . '), ' . $this->zoom_level . ');' . "\n"
 	        . '	map.addControl(new GSmallMapControl());' . "\n\n"      ;
 
 		// *********************************
 		// render markers
 		if (count($this->gmarkers)){
			$html .= $this->_populateMarkers()."\n\n";
 		}

 		// *********************************
 		// render listeners
 		if (count($this->events)){
 			$html .= $this->_populateEvents()."\n\n";
 		}
 		
 		
		$html .= '//]]></script>' . "\n";
		
		echo $html;	
	
	}
	
	
	/**
	 * GMap::addMarker()
	 * 
	 * @param object 		GPoint 
	 * @param object		GIcon
	 * @param object		GEvent :: in the JS the marker would be added to the event but in this case we will keep the event script with the marker
	 * @return boolean 		true on success falso on fail
	 */
	function addMarker($id,$pnt,$icn = null,$evt = null){
		
		if (!is_a($pnt,'GPoint')) return false;
		
		$this->gmarkers[] = new GMarker($id,$pnt,$icn,$evt);
		
		
	}
	
	
	/**
	 * GMap::addEvent()
	 * 
	 * @param string		
	 * @param string
	 * @param string		GEvent :: in the JS the marker would be added to the event but in this case we will keep the event script with the marker
	 * @return boolean 		true on success falso on fail
	 */
	function addEvent($evt){
		
		if (!is_a($evt,'GEvent')) return false;
		
		$this->events[] = $evt;
		
	}
	
	
	/**
	 * GMap::_populateMarkers
	 * 
	 * This function will loop through each of the markers and generate the javascript for each of them
	 * including initializing the marker and adding points and events
	 * The Markers should only have been added throught the interface This should be protected and probably
	 * will be in the php5 version
	 * 
	 * 
	 * 
	 * @return string HTML javascript of the GMarker elements to load
	 */
	function _populateMarkers(){
		
		if (!$mrks = $this->gmarkers) return false;
		$html = '';
		
		// loop through each of the markers
		if (is_array($mrks)){
			foreach ($mrks as $marker){
				
				$html .= $marker->generateInitScript();
				
			}
		}
		return $html;
	}
	
	
	
	
	
	
	/**
	 * GMap::_populateEvents
	 * 
	 * This function will loop through all the event listeners added to this object and display them
	 * This system is flexible and thus takes more effort to create the maps objects
	 * 
	 * 
	 * 
	 * @return string HTML javascript of the GEvent elements to load
	 */
	function _populateEvents(){
		
		if (!$evt = $this->events) return false;
		$html = '';
		
		// loop through each of the events
		if (is_array($evt)){
			foreach ($evt as $event){
				
				$html .= $event->generateScript();
				
			}
		}
		return $html;
	}
	
	
	/**
	 * GMap::setZoomLevel
	 * 
	 * @param int zoom level
	 */
	function setZoomLevel($zm){
		
		$this->zoom_level = $zm;	
		
	}




}
 
 
?>