<?php  /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Advanced Google Maps API PHP Abstraction implementation
 *
 * PHP 4 and 5
 *
 *
 * @category   Services
 * @package    GMap
 * @author     Steven J Scott <webmaster@sjscott.net>
 * @copyright  2005 SJScott Enterprise
 * @license    GPL
 * @version    $Id: GMarker.php,v 1.80 2005/02/16 02:16:00 LIQID Exp $
 * @link       http://www.sjscott.net
 */

class GMarker {

	/**
	 * GMarker::id
	 * 
	 * setting a unique id so that we can reuse names
	 * @var int marker id
	 */
	var $id = null;

	/**
	 * GMarker::point
	 * every marker has to be on a point 
	 * @var object GPoint object
	 */
	var $gpoint = null;
	
	/**
	 * GMarker::gevent
	 * some markers can have event listeners registered to themselves 
	 * TODO: need to create a function to validate the event listeners
	 * @var object GEvent object
	 */
	var $gevent = null;
	
	/**
	 * GMarker::gicon
	 * 
	 * 
	 * @var object GIcon
	 */
	var $gicon = null;
	
	/**
	 * constructor
	 * 
	 * @param object GPoint object
	 **/
    function GMarker($id,$pnt,$icn,$evt) {
		
		// only table a GPoint object
		if (!is_a($pnt,'GPoint')) return false;
		
		
		$this->gpoint 	= $pnt;
		$this->gicon 	= $icn;
		$this->gevent	= $evt;
		$this->id		= $id;

	}
	
	
	/**
	 * GMarker::generateScript
	 * This function will print out the equivilent of generating the object instantiation
	 * 
	 * @return string javascript form of the GMarker object
	 */
	function generateInitScript(){
		
		// TODO need to implement the gicon custom icon interface. 
		$gicon = ($this->gicon)? '':'';
		
		$html  = '	var point  = new GPoint('.$this->gpoint->point_lon.','.$this->gpoint->point_lat.'); '."\n";
		$html .= '	var '.$this->id.' = new GMarker(point);'."\n";

		if ($this->hasEvent()){
			// for this function we need to send the object that the event is being attached to
			// in this case with the id
			$html .= $this->gevent->generateScript($this->id)."\n";
		}
		
		$html .= '	map.addOverlay('.$this->id.')'."\n";
		
		return $html;
	}
	
	
	/**
	 * GMarker::hasListener
	 * 
	 * Checks this object to see if there is a listener assigned to the marker object
	 * be default a marker does not have a listener
	 */
	function hasEvent(){
		
		if ($this->gevent){
			return true;
		} else {
			return false;
		}
		
		
	}
	
	

}



?>